@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Padre::Constant ();
 
-our $VERSION = '0.58';
+our $VERSION = '0.59';
 
 # Get perl6 full executable path
 sub perl6_exe {
@@ -20,7 +20,15 @@ sub perl6_exe {
 
 	# On Windows, look for the Six distribution
 	if (Padre::Constant::WIN32) {
-		my $perl6 = "C:\\strawberry\\six\\perl6.exe";
+
+		# Find perl6.exe in PDX and later Six releases
+		my $perl6 = 'C:\\strawberry\\six\\bin\\perl6.exe';
+		if ( -f $perl6 ) {
+			return $perl6;
+		}
+
+		# Stay compatible with almost-six 0.41
+		$perl6 = 'C:\\strawberry\\six\\perl6.exe';
 		if ( -f $perl6 ) {
 			return $perl6;
 		}
@@ -50,7 +58,15 @@ sub parrot_bin {
 
 	# On Windows, look for the Six distribution
 	if (Padre::Constant::WIN32) {
-		my $command = "C:\\strawberry\\six\\parrot\\$exe";
+
+		# Find parrot binary in PDX and later Six releases
+		my $command = "C:\\strawberry\\six\\bin\\$exe";
+		if ( -f $command and -x _ ) {
+			return $command;
+		}
+
+		# Stay compatible with almost-six 0.41
+		$command = "C:\\strawberry\\six\\parrot\\$exe";
 		if ( -f $command and -x _ ) {
 			return $command;
 		}
